# Enable Python 3 builds for Fedora + EPEL >5
# NOTE: do **NOT** change 'epel' to 'rhel' here, as this spec is also
# used to do RHEL builds without EPEL
%if 0%{?fedora} || 0%{?epel} > 5
# If the definition isn't available for python3_pkgversion, define it
%{?!python3_pkgversion:%global python3_pkgversion 3}
%bcond_without  python3
%else
%bcond_with     python3
%endif

# Compatibility with RHEL. These macros have been added to EPEL but
# not yet to RHEL proper.
# https://bugzilla.redhat.com/show_bug.cgi?id=1307190
%{!?__python2: %global __python2 /usr/bin/python2}
%{!?python2_sitelib: %global python2_sitelib %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python2_sitearch: %global python2_sitearch %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%{!?py2_build: %global py2_build %{expand: CFLAGS="%{optflags}" %{__python2} setup.py %{?py_setup_args} build --executable="%{__python2} -s"}}
%{!?py2_install: %global py2_install %{expand: CFLAGS="%{optflags}" %{__python2} setup.py %{?py_setup_args} install -O1 --skip-build --root %{buildroot}}}


Name:       python-multilib
Version:    1.2
Release:        4.20170529git56582ce8%{?dist}
Summary:    A module for determining if a package is multilib or not
Group:      Development/Libraries
License:    GPLv2
URL:        https://pagure.io/releng/python-multilib
Source0:        python-multilib-56582ce8.tar

BuildArch:  noarch


%global _description \
A Python module that supports several multilib "methods" useful for \
determining if a 32-bit package should be included with its 64-bit analogue \
in a compose.

%description %{_description}

%package conf
Summary:        Configuration files for %{name}

%description conf
This package provides the configuration files for %{name}.

%package -n python2-multilib
Summary:        %{summary}
%{?python_provide:%python_provide python2-multilib}
BuildRequires:  python2-devel
BuildRequires:  python-setuptools
BuildRequires:  python-six
Requires:       python-six
Requires:       python2
Requires:       %{name}-conf = %{version}-%{release}

%description -n python2-multilib %{_description}

%if 0%{?with_python3}
%package -n python%{python3_pkgversion}-multilib
Summary:        %{summary}
%{?python_provide:%python_provide python%{python3_pkgversion}-multilib}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-six
Requires:       python%{python3_pkgversion}-six
Requires:       python%{python3_pkgversion}
Requires:       %{name}-conf = %{version}-%{release}

%description -n python%{python3_pkgversion}-multilib %{_description}
%endif


%prep
%setup -q -n %{name}

%build
%py2_build
%if 0%{?with_python3}
%py3_build
%endif

%install
%py2_install
%if 0%{?with_python3}
%py3_install
%endif

%check
#{__python2} setup.py test
#{__python3} setup.py test

%files conf
%config(noreplace) %{_sysconfdir}/multilib.conf

%files -n python2-multilib
%license LICENSE
%doc README.md
%{python2_sitelib}/*

%if 0%{?with_python3}
%files -n python%{python3_pkgversion}-multilib
%license LICENSE
%doc README.md
%{python3_sitelib}/*
%endif


%changelog
* Mon May 29 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.2-4.20170529git56582ce8
- Update to git: 56582ce8

* Thu Mar 02 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.2-3.20170302git42abcbad
- Update to git: 42abcbad

* Thu Mar 02 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.2-3.20170302git42abcbad
- Update to git: 42abcbad

* Thu Mar 02 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.2-3.20170302git42abcbad
- Update to git: 42abcbad

* Thu Mar 02 2017 lsedlar <lubomir.sedlar@gmail.com> - 1.2-3.20170302git42abcbad
- Update to git: 42abcbad

* Thu Mar 02 2017 Lubomír Sedlář <lsedlar@redhat.com> - 1.2-1
- New upstream version with support for DNF package objects
- Updated URL to point to new upstream on Pagure.io

* Sun May 01 2016 Neal Gompa <ngompa13@gmail.com> - 1.1-3
- Port to Python 3 and enable its subpackage
- Split config file to its own subpackage

* Thu Apr 07 2016 Dennis Gilmore <dennis@ausil.us> - 1.1-2
- setup to make python3 down the road.
- spec and srpm named python-multilib
- fix license

* Tue Jul 21 2009 Jay Greguske <jgregusk@redhat.com> - 1.1-1
- consider dependencies in multilib testing
- fix a couple import errors

* Tue Jul 21 2009 Jay Greguske <jgregusk@redhat.com> - 1.0-1
- Initial RPM release
